| flexCountReg-class | R Documentation |
A class to represent various objects created by the flexCountReg package.
modelThe fitted model object (can be any type).
dataThe data used for fitting the model (data frame).
formulaThe R formula used in the regression model (main formula, not including random parameters, etc.)
callThe matched call (language).
additionalAny additional information (list).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.