| rmse | R Documentation |
This function calculates the Root Mean Squared Error (RMSE) between observed and predicted values.
rmse(y, mu)
y |
Numeric vector representing the observed values. |
mu |
Numeric vector representing the predicted values. |
The RMSE is calculated using the formula:
RMSE = \sqrt{\frac{1}{n} \sum_{i=1}^{n} (y_i - \mu_i)^2}
Where y is the vector of observed values and \mu is the vector of
predicted values.
Numeric value representing the RMSE.
y <- c(1, 2, 3)
mu <- c(1.1, 1.9, 3.2)
rmse(y, mu)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.